@@ -1,4 +1,3 @@
 from .author import Author
 
-
-__all__ = ('Author',)
+__all__ = ("Author",)
