@@ -1,18 +1,18 @@
 import csv
 import os
 import sys
-import pytest
 
 import pylint
+import pytest
 
-
-os.environ.setdefault('DJANGO_SETTINGS_MODULE', 'pylint_django.tests.settings')
+os.environ.setdefault("DJANGO_SETTINGS_MODULE", "pylint_django.tests.settings")
 
 try:
     # pylint 2.5: test_functional has been moved to pylint.testutils
     from pylint.testutils import FunctionalTestFile, LintModuleTest
 
     if "test" not in csv.list_dialects():
+
         class test_dialect(csv.excel):
             delimiter = ":"
             lineterminator = "\n"
@@ -20,16 +20,16 @@ try:
         csv.register_dialect("test", test_dialect)
 except (ImportError, AttributeError):
     # specify directly the directory containing test_functional.py
-    test_functional_dir = os.getenv('PYLINT_TEST_FUNCTIONAL_DIR', '')
+    test_functional_dir = os.getenv("PYLINT_TEST_FUNCTIONAL_DIR", "")
 
     # otherwise look for in in ~/pylint/tests - pylint 2.4
     # this is the pylint git checkout dir, not the pylint module dir
     if not os.path.isdir(test_functional_dir):
-        test_functional_dir = os.path.join(os.getenv('HOME', '/home/travis'), 'pylint', 'tests')
+        test_functional_dir = os.path.join(os.getenv("HOME", "/home/travis"), "pylint", "tests")
 
     # or site-packages/pylint/test/ - pylint before 2.4
     if not os.path.isdir(test_functional_dir):
-        test_functional_dir = os.path.join(os.path.dirname(pylint.__file__), 'test')
+        test_functional_dir = os.path.join(os.path.dirname(pylint.__file__), "test")
 
     sys.path.append(test_functional_dir)
 
@@ -38,33 +38,35 @@ except (ImportError, AttributeError):
 
 # alter sys.path again because the tests now live as a subdirectory
 # of pylint_django
-sys.path.append(os.path.join(os.path.dirname(__file__), '..', '..'))
+sys.path.append(os.path.join(os.path.dirname(__file__), "..", ".."))
 # so we can find migrations
-sys.path.append(os.path.join(os.path.dirname(__file__), 'input'))
+sys.path.append(os.path.join(os.path.dirname(__file__), "input"))
 
 
 class PylintDjangoLintModuleTest(LintModuleTest):
     """
-        Only used so that we can load this plugin into the linter!
+    Only used so that we can load this plugin into the linter!
     """
+
     def __init__(self, test_file):
         super(PylintDjangoLintModuleTest, self).__init__(test_file)
-        self._linter.load_plugin_modules(['pylint_django'])
+        self._linter.load_plugin_modules(["pylint_django"])
         self._linter.load_plugin_configuration()
 
 
 class PylintDjangoMigrationsTest(PylintDjangoLintModuleTest):
     """
-        Only used so that we can load
-        pylint_django.checkers.migrations into the linter!
+    Only used so that we can load
+    pylint_django.checkers.migrations into the linter!
     """
+
     def __init__(self, test_file):
         super().__init__(test_file)
-        self._linter.load_plugin_modules(['pylint_django.checkers.migrations'])
+        self._linter.load_plugin_modules(["pylint_django.checkers.migrations"])
         self._linter.load_plugin_configuration()
 
 
-def get_tests(input_dir='input', sort=False):
+def get_tests(input_dir="input", sort=False):
     def _file_name(test):
         return test.base
 
@@ -73,7 +75,7 @@ def get_tests(input_dir='input', sort=False):
 
     suite = []
     for fname in os.listdir(input_dir):
-        if fname != '__init__.py' and fname.endswith('.py'):
+        if fname != "__init__.py" and fname.endswith(".py"):
             suite.append(FunctionalTestFile(input_dir, fname))
 
     # when testing the migrations plugin we need to sort by input file name
@@ -86,7 +88,7 @@ def get_tests(input_dir='input', sort=False):
 
 
 TESTS = get_tests()
-TESTS.extend(get_tests('input/models'))
+TESTS.extend(get_tests("input/models"))
 TESTS_NAMES = [t.base for t in TESTS]
 
 
@@ -99,7 +101,7 @@ def test_everything(test_file):
 
 
 # NOTE: define tests for the migrations checker!
-MIGRATIONS_TESTS = get_tests('input/migrations', True)
+MIGRATIONS_TESTS = get_tests("input/migrations", True)
 MIGRATIONS_TESTS_NAMES = [t.base for t in MIGRATIONS_TESTS]
 
 
@@ -110,5 +112,5 @@ def test_migrations_plugin(test_file):
     LintTest._runTest()
 
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     sys.exit(pytest.main(sys.argv))
